==> maven-dependency-analyzer_1.10.orig.tar.xz: maven-dependency-analyzer-maven-dependency-analyzer-1.10/src/main/java/org/apache/maven/shared/dependency/analyzer/asm/DefaultSignatureVisitor.java <==
package org.apache.maven.shared.dependency.analyzer.asm;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.objectweb.asm.Opcodes;
import org.objectweb.asm.signature.SignatureVisitor;

/**
 * Computes the set of classes referenced by visited code.
 * Inspired by <code>org.objectweb.asm.depend.DependencyVisitor</code> in the ASM dependencies example.
 *
 * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
 * @version $Id$
 */
public class DefaultSignatureVisitor
    extends SignatureVisitor
{
    private final ResultCollector resultCollector;

    public DefaultSignatureVisitor( ResultCollector resultCollector )
    {
        super( Opcodes.ASM6 );
        this.resultCollector = resultCollector;
    }

    public void visitClassType( final String name )
    {
        resultCollector.addName( name );
    }

    public void visitInnerClassType( final String name )
    {
        resultCollector.addName( name );
    }
}

==> maven-dependency-analyzer_1.14.1.orig.tar.xz: maven-dependency-analyzer-maven-dependency-analyzer-1.14.1/src/main/java/org/apache/maven/shared/dependency/analyzer/asm/DefaultSignatureVisitor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.shared.dependency.analyzer.asm;

import org.objectweb.asm.Opcodes;
import org.objectweb.asm.signature.SignatureVisitor;

/**
 * Computes the set of classes referenced by visited code.
 * Inspired by <code>org.objectweb.asm.depend.DependencyVisitor</code> in the ASM dependencies example.
 *
 * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
 */
public class DefaultSignatureVisitor extends SignatureVisitor {
    private final ResultCollector resultCollector;

    /**
     * <p>Constructor for DefaultSignatureVisitor.</p>
     *
     * @param resultCollector a {@link org.apache.maven.shared.dependency.analyzer.asm.ResultCollector} object.
     */
    public DefaultSignatureVisitor(ResultCollector resultCollector) {
        super(Opcodes.ASM9);
        this.resultCollector = resultCollector;
    }

    /** {@inheritDoc} */
    @Override
    public void visitClassType(final String name) {
        resultCollector.addName(name);
    }

    /** {@inheritDoc} */
    @Override
    public void visitInnerClassType(final String name) {
        resultCollector.addName(name);
    }
}
